#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_FLOOR_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_FLOOR_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/floor.hpp>

#endif
